#ifndef TPG300_H
#define TPG300_H

#include <QWidget>
#include <QtGui>

#include <qextserialport.h> // gestion des connexions RS232

#include "ui_tpg300.h" // interface graphique
#include "fenetre_rs232.h" // fenetre de configuration RS232
#include "fenetre_parametres.h" // fenetre de configuration de la mesure
#include "fenetre_ma.h" // fenetre de configuration du mode
#include "fenetre_tsp.h" // fenetre de configuration de la consigne
#include "fenetre_top.h" // fenetre de configuration de la puissance
#include "threadtpg300.h" // gestion du thread pour les mesures

class TPG300 : public QMainWindow
{
  Q_OBJECT

// variables et fonctions
public:
  TPG300(QWidget *parent = 0); // constructeur

  Ui::TPG300 ui; // interface graphique principale
  RS232 fenetre_rs232; // fenetre pour configurer la connexion RS232
  PARAMETRES fenetre_parametres; // fenetre pour configurer la mesure
  MA fenetre_ma; // fenetre pour configurer le mode
  TSP fenetre_tsp; // fenetre pour configurer la consigne
  TOP fenetre_top; // fenetre pour configurer la puissance

  QextSerialPort *port; // sert a communiquer par le port serie

  RenderThread thread; // le thread qui lit les donnees de mesure


  void affichage_moniteur(QString la_commande); // permet d'afficher sur le moniteur

  // envoi et reception
  int send_rs232_char(char *la_commande, int nb_octets); // envoyer vers l'appareil 2704
  void receive_rs232_char(char *la_commande, int nb_octets); // recevoir une ligne de l'appareil 2704
  void receive_rs232_rapide(void); // recevoir tout ce qui est a recevoir

  // les fonctions de dialogue
  QString getsp(void); // 902 Get SP = Consigne de travail
  QString getop(void); // 902P Get OP [Parametre Puissance de sortie]
  QString getpv(void); // 901P Get PV [Parametre Mesure temperature]
  QString getmode(void); // 902P Get Mode 

  void setsp(double val); // 902P change consigne
  void setop(double val); // 902P change puissance
  void setmode(int val); // 902P change Mode


  unsigned int Crc16(unsigned char *Adresse_tab , unsigned char Taille_max);
  QString bcc(unsigned char *Adresse_tab , int taille);

  void mesure(void); // fonction appelee tous les x secondes pour faire les mesures

  QString nom_file; // nom du fichier de stockage des donnees
  QDateTime date_init; // heure de debut
  int nb_cycles; // nombre de cycles de mesures

// les elements du UI
public slots:
  void on_pushButton_1_1_clicked();  // configuration RS232
  void on_pushButton_1_2_clicked();  // configuration paramtres
  void on_pushButton_1_3_clicked();  // connexion a l'appareil

  void on_pushButton_clicked();  // consigne de travail
  void on_pushButton_2_clicked();  // puissance de sortie
  void on_pushButton_3_clicked();  // mode

};

#endif
